pub struct DbAciRecord {
pub app_id: String,
pub name: String,
pub cmd_path: String,
pub node_type: String,
pub description: String,
pub risk_level: String,
pub example_template: Option<String>,
pub install_instructions: Option<String>,
pub docker_image: Option<String>,
pub script_url: Option<String>,
pub source_url: Option<String>,
}Expand description
Flattened database record representing the JOIN of arguments and apps.
This provides the exact structure returned by combining a specific CLI command/argument with its parent app metadata.
Fields
app_id: Stringname: Stringcmd_path: Stringnode_type: Stringdescription: Stringrisk_level: Stringexample_template: Option<String>install_instructions: Option<String>docker_image: Option<String>script_url: Option<String>source_url: Option<String>Trait Implementations
Sourceimpl Clone for DbAciRecord
impl Clone for DbAciRecord
Sourcefn clone(&self) -> DbAciRecord
fn clone(&self) -> DbAciRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DbAciRecord
impl Debug for DbAciRecord
Sourceimpl<'de> Deserialize<'de> for DbAciRecord
impl<'de> Deserialize<'de> for DbAciRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DbAciRecord
Sourceimpl PartialEq for DbAciRecord
impl PartialEq for DbAciRecord
Sourcefn eq(&self, other: &DbAciRecord) -> bool
fn eq(&self, other: &DbAciRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DbAciRecord
impl Serialize for DbAciRecord
impl StructuralPartialEq for DbAciRecord
Sourceimpl TryFrom<DbAciRecord> for AciCommandContract
impl TryFrom<DbAciRecord> for AciCommandContract
Sourcetype Error = CmdHubError
type Error = CmdHubError
The type returned in the event of a conversion error.